@@ -22,6 +22,9 @@ from . import logging  # noqa: F401
 from . import ipyvuetify as v
 from . import ipywidgets as w
 from .core import ipywidget_version_major
+from .patch_display import patch as patch_display
+
+patch_display()
 
 T = TypeVar("T")
 
@@ -2724,13 +2727,17 @@ def test_implicit_component():
 
 def test_create_widget():
     @react.component
-    def Test(a: int = 1, label="lala", on_a=None):
+    def Test(a: int = 1, label="lala", on_a=None, children=[]):
+        # adding children shouldn't change the children trait
+        assert children == []
         return w.IntSlider(value=a, on_value=on_a, description=label)
 
-    widget: widgets.Widget = Test.widget(a=1, label="lala")  # type: ignore
+    widget: widgets.Widget = Test.widget(a=1)  # type: ignore
+    assert widget.trait_metadata("children", "to_json") is not None
     mock = unittest.mock.Mock()
     widget.trait_names() == ["a", "label"]
     widget.observe(mock, "a")
+    assert widget.label == "lala"
     widget.a = 2
     mock.assert_called_once_with({"name": "a", "old": 1, "new": 2, "owner": widget, "type": "change"})
     slider = widget.children[0]
@@ -2794,3 +2801,36 @@ def test_display_dataframe():
     box, rc = react.render(Test(), handle_error=False)
     # assert rc.find(widgets.Button).widget.description == "hoeba"
     rc.close()
+
+
+def test_component_context_manager():
+    calls = 0
+
+    class ContextManager:
+        def __init__(self, el) -> None:
+            pass
+
+        def __enter__(self):
+            nonlocal calls
+            calls += 1
+
+        def __exit__(self, *args):
+            pass
+
+    def set_text(text: str):
+        pass
+
+    reacton.core._component_context_manager_classes.append(ContextManager)
+
+    @react.component
+    def Test():
+        nonlocal set_text
+        text, set_text = reacton.use_state("hoeba")  # type: ignore
+        return w.Button(description=text)
+
+    box, rc = react.render(Test(), handle_error=False)
+    assert calls == 1
+    set_text("different")
+    assert calls == 2
+    rc.close()
+    reacton.core._component_context_manager_classes.pop()
